@@ -4,12 +4,12 @@
 #include <R_ext/Rdynload.h>
 
 /* .Call calls */
-extern SEXP clampSeg_deconvolveJump(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
-extern SEXP clampSeg_deconvolvePeak(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
+extern SEXP _clampSeg_deconvolveJump(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
+extern SEXP _clampSeg_deconvolvePeak(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 
 static const R_CallMethodDef CallEntries[] = {
-  {"clampSeg_deconvolveJump", (DL_FUNC) &clampSeg_deconvolveJump,  8},
-  {"clampSeg_deconvolvePeak", (DL_FUNC) &clampSeg_deconvolvePeak, 10},
+  {"_clampSeg_deconvolveJump", (DL_FUNC) &_clampSeg_deconvolveJump,  8},
+  {"_clampSeg_deconvolvePeak", (DL_FUNC) &_clampSeg_deconvolvePeak, 10},
   {NULL, NULL, 0}
 };
 
